@@ -1,8 +1,11 @@
-import pandas , ssl
+import ssl
+import pandas
+
 
 # To Override the SSL Error of '[SSL: CERTIFICATE_VERIFY_FAILED]'. 
 ssl._create_default_https_context = ssl._create_unverified_context
 
+
 class Helper:
     def get_Wikis_Codes():
         url = r'https://en.wikipedia.org/wiki/List_of_Wikipedias'
